Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*options)
Option function
func WithBufferSize ¶
Buffer size that specifies how big batches are processed written to logstash service at once. Minimum is 1
func WithContext ¶
WithContext should be used when context will expire/ be canceled so the rest of the buffer is sent to logstash Alternativelly use Flush(time.Duration) function
Click to show internal directories.
Click to hide internal directories.